`hdpmPredict` <-
function(j=1,   # study index
                          r=0,   # indicator for including the common measure
                          i=NULL,   # which patient (line in init.p)
                          work.dir=NULL, # directory for result files
                          plt=T)   # indicator for plotting 
{## plot posterior predictive for study j, using
 ## the idiosyncratic measure only (r=1) or including the common m. (r=0)

  ## 1. change working directory (if required..)
  if(!is.null(work.dir)){
    cat("\n Changing working directory to ",work.dir,"\n")
    old.dir <- getwd()  # by default work in current working directory
    setwd(work.dir)
  } 

  ## 2.check parameters
  if ( (length(r)>1) | (length(j)>1)){
    cat("\n *** Error: r and j need to be single integers.\n")
    return(-1)
  }
  if (!is.element(r,c(0,1))){ # r=0 or 1?
    cat("\n *** Error: need r = 0 or 1.\n")
    cat("    r=0: include common measure; r=1 idiosyncratic only.\n")
    return(-1)
  }

  xgrid <- scan("xgrid.p")
  nx <- length(xgrid)
  ## matrix of covariates 'x-jr.p'
  fn <- fjr("x",j,r)
  if (!file.exists(fn)){
    cat("\n *** Error: simulation results for (j,r)=",c(j,r))
    cat("\n     not found in directory ", work.dir)
    cat("\n Run 'hdpmPredictSetup(.) first with (j,r).\n")
    return(-1)
  }
  X <- as.matrix(read.table(fn))
  npa <- nrow(X)
  if(is.null(i))
    i <- 1:npa
  else if(!is.element(i,1:npa)){
    cat("\n *** Error: need i \in {1,...,",npa,"}.")
    cat("\n (number of lines in 'x-jr.p'.\n")
    return(-1)
  }
  ## posterior predictive profiles 'e-jr.p', over xgrid
  fn <- fjr("e",j,r)
  dta <- scan(fn)
  if (length(dta) %% nx != 0){
    cat("\n *** Error: 'xgrid.p' and 'e-jr.p' are not compatible.")
    cat("\n 'e-jr.p' does not have length(xgrid) columns for each patients.")
    cat("\n (j,r)=",c(j,r),"\n")
    return(-1)
  }
  if (length(dta) != nx*npa){
    cat("\n *** Error: length(e-jr.p) != nrow(x-jr.p)*length(xgrid.p).\n")
    cat("\n (j,r)=",c(j,r),"\n")
    return(-1)
  }
  e <- matrix(dta,byrow=T,ncol=nx)
  ## ... and s.d. 's-jr.p'
  fn <- fjr("s",j,r)
  dta <- scan(fn)
  s <- matrix(dta,byrow=T,ncol=nx)
  ## plot if requested
  if(plt){
    ylim <- range(c(e-s,e+s))
    if(length(i)>1)
      matplot(xgrid,t(e[i,]),type="l",xlab="TIME",ylab="PREDICTIVE RESP",
              bty="l")
    else{
      plot(xgrid,e[i,],type="l",
           ylim=ylim,xlab="TIME",ylab="PREDICTIVE RESP",bty="l")
      lines(xgrid,e[i,]+s[i,],type="l",lty=2)
      lines(xgrid,e[i,]-s[i,],type="l",lty=2)
    }
  }

  ## change back working directory (if necessary..)
  if(!is.null(work.dir)){
    cat("\n Changing working directory back to ",old.dir,"\n")
    setwd(old.dir)
  }
  return(list(xgrid=xgrid,e=e[i,],s=s[i,],x=X[i,]))
}

fjr <- function(nm,j,r)
  {# construct file name for study j, indicator r
    return(paste(nm,"-",j,r,".p",sep=""))
  }
