source("/Users/pm/s/first.s")
dir <- "/Users/pm/smooth/R/meta2/"

n <- NULL          # sample size (n responses)
npatients <- NULL  # patients
nstudies <- NULL   # number of submodels (studies)
py <- NULL         # dim of response
n.iter <- 1000    # n MCMC iterations
n.discard <- 100  # initial transient
n.batch <- 50      # batch size to thin out
mcmc.c <- 1.0      # step size for MH
verbose <- 3       # 0 <- no commens
seed1 <- 981963    # r.v. seeds
seed2 <- 6869504 
mcmc.eps <- 0      # indicator for sampling epsilon
sig <- 1.0         # initial residual error
as <- 2.0          # sig^2 ~ IG(as/2 bs/2)
bs <- 2.0 
eps <- 0.1         # prob idiosyncratic cluster
ae <- 1            # p(eps) ~ pe0*I(0)+pe1*I(1)+
## (1-pe0-pe1)*Be(ae,be)
be <- 1 
pe1 <- 0.1         #
pe0 <- 0.1 
## pars for DP mixture r.e. prior
pz <- NULL         # dimension of random eff (incl cov's)
px <- 3            # dim of covariate vector
m.prior <- 0       # resample m
B.prior <- 0       # resample B
S.prior <- 0       # resample S
alpha.prior <- 0   # resample alpha
n.predupdate <- 100    

S.init <- NULL     # initial value and prior mean for S
q <- 5             # d.f. for prior on S, 1/S ~ W(q,1/(qR)]
R <- NULL          # hyperprior mean for S
B.init <- NULL     # initial value for B in G0(mu) <- N(m,B)
cc <- 5            # d.f. par c for prior 1/B ~ W(c,1/(cC))
C <- NULL          # hyperprior par C
m.init <- NULL     # initial values for m
a <- NULL          # hyperpar a for prior m ~ N(a,A)
A <- NULL          # hyperpar A

alpha <- 1         # initial value for total mass alpha
a0 <- 1 
b0 <- 1            # hyperprior pars for alpha ~ IG(a0/2,b0/2)
k0 <- NULL         # initial number of clusters
header=TRUE

Y <- "CALBG.txt"
Z <- "CALGBz.txt"
data.dir <- dir

## main function to run MCMC
meta <- function(
                 Y=NULL,         # data (could be alphanumeric filename)
                 Z=NULL,         # initial r.e. and covariates (matrix or fn)
                 n=NULL,         # sample size (n responses)
                 npatients=NULL, # patients
                 nstudies=NULL,  # number of submodels (studies)
                 py=NULL,        # dim of response
                 n.iter=1000,   # n MCMC iterations
                 n.discard=100, # initial transient
                 n.batch=50,     # batch size to thin out
                 mcmc.c=1.0,     # step size for MH
                 verbose=3,      # 0=no commens
                 seed1=981963,   # r.v. seeds
                 seed2=6869504,
                 mcmc.eps=0,     # indicator for sampling epsilon
                 sig=1.0,        # initial residual error
                 as=2.0,         # sig^2 ~ IG(as/2,bs/2)
                 bs=2.0,
                 eps=0.1,        # prob idiosyncratic cluster
                 ae=1,           # p(eps) ~ pe0*I(0)+pe1*I(1)+
                 ## (1-pe0-pe1)*Be(ae,be)
                 be=1,
                 pe1=0.1,        #
                 pe0=0.1,
                 ## pars for DP mixture r.e. prior
                 pz=NULL,        # dimension of random eff (incl cov's)
                 px=NULL,        # dim of covariate vector
                 m.prior=0,      # resample m
                 B.prior=0,      # resample B
                 S.prior=0,      # resample S
                 alpha.prior=0,  # resample alpha
                 n.predupdate=100,   

                 S.init=NULL,    # initial value and prior mean for S
                 q=5,            # d.f. for prior on S, 1/S ~ W(q,1/(qR)]
                 R=NULL,         # hyperprior mean for S
                 B.init=NULL,    # initial value for B in G0(mu)=N(m,B)
                 cc=5,           # d.f. par c for prior 1/B ~ W(c,1/(cC))
                 C=NULL,         # hyperprior par C
                 m.init=NULL,    # initial values for m
                 a=NULL,         # hyperpar a for prior m ~ N(a,A)
                 A=NULL,         # hyperpar A
                 
                 alpha=1,        # initial value for total mass alpha
                 a0=1,
                 b0=1,           # hyperprior pars for alpha ~ IG(a0/2,b0/2)
                 k0=NULL,        # initial number of clusters
                 data.dir=NULL,  # directory to work in
                 header=T)       # indicator for headers in Y and Z files
{
  options(digits=2)

  if(is.null(data.dir))
    data.dir <- getwd()  # by default work in current working directory
  
  ## initialization file init.giis for MCMC:
  ## 1. check basic parameters
  if(is.null(Y)){
    cat("\n *** Error: must specify data Y (matrix or filename).\n")
    return(-1)
  }
  if(!is.numeric(Y)){
    fn <- file.path(data.dir,Y)
    dta <- read.table(fn,header=header)
    if (is.null(dta)){ ## reading in data did not work
      cat("\n *** Error: could not read data from file",Y,
          "\n Hint: need to include full path.\n")
      return(-1)
    }
    if (verbose>0){
      cat("Read ", nrow(dta), " rows and ", ncol(dta), " columns",
          "from data file ", Y,"\n")
      if (header)
        cat("First line is interpreted as variable names.\n")
    }
    Y <- as.matrix(dta)
  }
  if(is.null(n))
    n <- nrow(Y)
  else
    if (n != nrow(Y)){
      cat("\n *** Error: nrows(Y) != n. Need to match.\n")
      return(-1)
    }
  if(is.null(py))
    py <- ncol(Y)
  else
    if(py != ncol(Y)){
      cat("\n *** Error: ncol(Y) != py. Need to match.\n")
      cat(
      "\n Note: py needs to include the last column for the study indicator.\n")
      return(-1)
    }
  stdy <- Y[,py]    # should be indicator for submodel (study)
  if (sum(stdy-round(stdy))>0){ # it's not only integers!
    cat("\n *** Error: last column of dta matrix should be study indicator.\n")
    return(-1)
  }
  if (min(stdy)!= 1){
    cat("\n *** Error: studies need to be indexed 1,2,..,nstudies-1.\n")
    cat("    But finding study index 0.")
    cat(" Note: 1. start indexing with '1' (0 is the common measure).\n")
    cat("       2. Last index is nstudies-1 (!),")
    cat(" saving j=nstudies for a future st.\n")
    return(-1)
  }
  if (length(unique(stdy)) != max(stdy)){ # studies should be labeled 1,2,..
    cat("\n *** Error: studies need to be indexed 1,2,..,nstudies-1.\n")
    cat(" Note: 1. start indexing with '1' (0 is the common measure).\n")
    cat("       2. Last index is nstudies-1 (!),")
    cat(" saving j=nstudies for a future st.\n")
    return(-1)
  }
  if (is.null(nstudies))
    nstudies <- max(stdy)+1
  if (nstudies != max(stdy)+1){
    cat("\n *** Error: nstudies does not match last column of Y.\n")
    cat(" Should be max(last column) + 1 (for future study).\n")
    return(-1)
  }
  pats <- Y[,1]
  if (sum(abs(pats-round(pats)))>0){ # not only integers
    cat("\n *** Error: 1st column of Y should be patient index.\n")
    return(-1)
  }
  if (max(pats)+1 != length(unique(pats))){ # not numbered 1,..,npats
    cat("\n *** Error: patients must be indexed 0,2,..,npatients-1.\n")
    cat(" NOTE: start indexing with '0' for the 1st patient.\n")
    return(-1)
  }
  if (is.null(npatients))
    npatients <- length(unique(pats))
  else
    if (npatients != length(unique(pats))){
      cat("\n *** Error: npatients does not match patient indices.\n")
      return(-1)
    }
  nb <- 2    # for logistic regressin in lpost.c
  model <- 0 # logistic model
  if (n.discard >= n.iter){
    cat("\n *** Error: n.iter <= n.discard. \n")
    return(-1)
  }
  if (n.batch >= n.iter/2){
    cat("\n *** Error: n.iter/2 <= n.batch. \n")
    return(-1)
  }
  if (pe1+pe0 >= 1.0){
    cat("\n *** Error: need pe0+pe1 < 1.\n")
    return(-1)
  }
  if (!is.element(mcmc.eps,c(0,10))){
    cat("\n *** Error: mcmc.eps not in {0,1}.\n")
    return(-1)
  }
  if ((eps<0) | (eps>1)){
    cat("\n *** Error: eps not in [0,1].\n")
    return(-1)
  }

  ## read in initial values for random effects and covariates
  ## (need pz for 'init.giis')
  if(is.null(Z)){
    cat("\n *** Error: must specify ",
        " initial random effects Z (matrix or filename).\n")
    return(-1)
  }
  if(!is.numeric(Z)){
    fn <- file.path(data.dir,Z)
    dta <- read.table(fn,header=header)
    if (is.null(dta)){ ## reading in data did not work
      cat("\n *** Error: could not read data from file",Z,
          "\n Hint: need to include full path.\n")
      return(-1)
    }
    if (verbose>0){
      cat("Read ", nrow(dta), " rows and ", ncol(dta), " columns",
          "from random effects file ", Z,"\n")
      if (header)
        cat("First line is interpreted as variable names.\n")
    }
    Z <- as.matrix(dta)
  }
  if (npatients < nrow(Z)){
      cat("\n *** Warning: nrows(Z) > npatients. \n")
      cat("    Note: this might be intended for predictive inference?\n")
    }
  if (npatients > nrow(Z)){
      cat("\n *** Error: nrows(Z) < npatients. Need npatients <= nrow(Z).\n")
    }
  if(is.null(pz))
    pz <- ncol(Z)
  if(pz != ncol(Z)){
    cat("\n *** Error: ncol(Z) != pz. Need to match.\n")
    return(-1)
  }

  fn <- file.path(data.dir,"init.giis")
  out <- file(fn,open="w")
  cat("data-npatients ",npatients,"\n",
      "data-nstudies ", nstudies, "\n",
      "model-nb 2 \n",
      "model-p1 ", pz, "\n",
      "model-model 0 \n",
      "data-N ", n, "\n",
      "data-dim ", py, "\n",
      "mcmc-niter", n.iter, "\n",
      "mcmc-npi ", n.batch, "\n",
      "mcmc-nbatch 5 \n",
      "mcmc-ndiscard ",n.discard, "\n",
      "mcmc-c ", mcmc.c, "\n",
      "mcmc-verbose ", verbose, "\n",
      "mcmc-seed1 ", seed1, "\n",
      "mcmc-seed2 ", seed2, "\n",
      "mcmc-eps ", mcmc.eps, "\n",
      "model-sig ", sig, "\n",
      "model-as ", as, "\n",
      "model-bs ", bs, "\n",
      "model-eps ", eps, "\n",
      "model-ae ", ae,   "\n",
      "model-be ", be,   "\n",
      "model-pe1 ", pe1, "\n",
      "model-pe0 ", pe0, "\n",
        file=out)
  close(out)

  ## initialization file init.mdp for MDP model
  if (is.null(px)){
    cat("\n **** Error: need px=dim(covariate vector).")
    cat("\n      Note:  px < pz = ncol(Z).\n")
    return(-1)
  }
    
  if (px >= pz){
    cat("\n Error: dim(covariates) >= dim(r.e. and covariates), ",
        "i.e., px>=pz. Can't be.\n")
    return(-1)
  }
  ## moments of initial r.e. for initializations..
  pzi <- pz-px # random effects only
  mhat <- apply(Z,2,mean)
  V <- var(Z)
  v <- diag(V)
  
  if (!is.null(S.init))
    if ( (nrow(S.init) != pz) | (ncol(S.init) != pz)){
      cat("\n *** Error: dim(S.init) != (pz x pz).\n")
      cat(" Note: S includes the covariates!.\n")
      return(-1)
    }
  if (!is.null(B.init))
    if ( (nrow(B.init) != pz) | (ncol(B.init) != pz)){
      cat("\n *** Error: dim(B.init) != (pz x pz).\n")
      cat(" Note: B includes the covariates!.\n")
      return(-1)
    }
  if (!is.null(C))
    if ( (nrow(C) != pz) | (ncol(C) != pz)){
      cat("\n *** Error: dim(C) != (p x p).\n")
      cat(" Note: dim(C) includes the covariates!.\n")
      return(-1)
    }
  if (!is.null(A))
    if ( (nrow(A) != pz) | (ncol(A) != pz)){
      cat("\n *** Error: dim(A) != (p x p).\n")
      cat(" Note: dim(A) includes the covariates!.\n")
      return(-1)
    }
  if (!is.null(m.init))
    if (length(m.init) != pz){
      cat("\n *** Error: length(m) != p.\n")
      cat(" Note: dim(m) includes the covariates!.\n")
      return(-1)
    }
  if (!is.null(a))
    if (length(a) != pz){
      cat("\n *** Error: length(a) != p.\n")
      cat(" Note: dim(a) includes the covariates!.\n")
      return(-1)
    }

  ## 2. default parameters
  if(is.null(S.init)){
    S.init <- 0.25*V
    cat(" setting default for S.init = 1/4*var(Z).\n")
  }
  if(is.null(R)){
    R <- 0.25*diag(v)
    cat(" setting default for R = 1/4*diag(var(Z)).\n")
  }
  if(is.null(B.init)){
    B.init <- diag(v)
    cat(" setting default for B.init = var(var(Z)).\n")
  }
  if(is.null(m.init)){
    m.init <- mhat
    cat(" setting default for m.init = column mean(Z).\n")
  }
  if(is.null(C)){
    C <- diag(v)
    cat(" setting default for C = diag(var(Z)).\n")
  }
  if(is.null(A)){
    A <- diag(v)
    cat(" setting default for A = diag(diag(Z)).\n")
  }
  if(is.null(a)){
    a <- mhat
    cat(" setting default for a = column mean(Z).\n")
  }
  if(is.null(k0)){
    k0 <- npatients
    cat(" setting default for k0=npatients.\n")
  }
  if ( (k0 != 1) & (k0 != npatients)){
    cat("\n *** Error: k0 \not\in {1,n}.\n")
    return(-1)
  }
  if (!is.element(m.prior,c(0,1))){
    cat("\n *** Error: m.prior = 0 or 1 required.\n")
    return(-1)
  }
  if (!is.element(B.prior,c(0,1))){
    cat("\n *** Error: B.prior = 0 or 1 required.\n")
    return(-1)
  }
  if (!is.element(alphaprior,c(0,1))){
    cat("\n *** Error: alpha.prior = 0 or 1 required.\n")
    return(-1)
  }
  
  ## 3. warnings
  if (cc < p+2)
    cat(" *** Warning: should use c > p+2 for good mixing MCMC.\n")
  if (q < p+2)
    cat(" *** Warning: should use q > p+2 for good mixing MCMC.\n")
  if (s < p+2)
    cat(" *** Warning: should use s > p+2 for good mixing MCMC.\n")
    
  ## 3. write init file
  fn <- file.path(data.dir,"init.mdp")
  out <- file(fn,open="w")
  cat(" data-p ",pz,
        "\n model-m_prior ", m.prior,
        "\n model-B_prior ", B.prior,
        "\n model-S_prior ", S.prior,
        "\n model-alpha_prior ", alpha.prior,
        "\n mcmc-npredupdate ", n.predupdate,
        "\n par-S \n", rbind( format(S.init),"\n"),
        "\n par-q ", q,
        "\n par-R  \n", rbind( format(R),"\n"),
        "\n par-B \n", rbind(format(B.init),"\n"),
        "\n par-c ", cc,
        "\n par-C \n ", rbind(format(C),"\n"),
        "\n par-m ", format(m.init),
        "\n par-aa ", format(a),
        "\n par-Ainv \n", rbind( format(solve(A)),"\n"),
        "\n par-alpha ", alpha,
        "\n par-aalpha ", a0, 
        "\n par-balpha ", b0, 
        "\n init-k0 ", k0, "\n",
        file=out)
  close(out)

  ## 4. write data file
  fn <- file.path(data.dir,"data.giis")
  out <- file(fn,open="w")
  cat("data-y \n",file=out)
  write(format(t(Y)),ncolumns=py,file=out)
  close(out)

  fn <- file.path(data.dir,"data-z.giis")
  out <- file(fn,open="w")
  cat("data-z \n",file=out)
  write(format(t(Z)),ncolumns=pz,file=out)
  close(out)
  
  ## 4. call C executable
  info <- .C("meta",package="meta")
  if (verbose>1){
    cat(" Results are saved in files 'xxx.mdp' and 'xxx.giis'. \n")
    cat(" in directory ", data.dir,". \n")
  }

  
  ## 5. return error code
  return(info)
}

    
##################################################################
# functions to make predictive plots
##################################################################

r <- 0; j <- 1; n <- 100; p <- 10; xgrid <- c(0,22); px <- 3; nx <- 22;
sig <- 1; n <- 100
dir <- "/Users/pm/smooth/R/meta2/"

meta.predictSetup <-
  function(j=1,     # study index
           r=0,     # indicator for including (0) or not (1) the common msr
           n=100,   # max MCMC iterations to use
           p=NULL,  # dimension of data records (including covariates)
           sig=1,   # residual variance
           nx=22,   # size of grid for posteriore predictive profile
           xgrid=NULL, # grid for predictive
           npa=NULL,   # number of future patients
           px=NULL,    # size of covariate vector
           X=NULL,     # (npa x px) matrix of covariates for future pat's
           dir=NULL,   # directory to find the working files from meta..
           header=T)
{# computes posterior predictive for future patients
  if(is.null(dir))
    dir <- getwd()
  cat("\n Looking for working files in directory ",dir,".\n")

  if(!is.numeric(X)){
    fn <- file.path(data.dir,X)
    dta <- read.table(fn,header)
    X <- as.matrix(dta)
  }
  if (!is.null(p)){
    if (p != ncol(X)){
      cat("\n *** Error: need p=ncol(X).")
      cat("   Note: X should include dummy random effects (use 0, e.g.).\n")
      return(-1)
    }
  } else
  p <- ncol(X)
  if(is.null(npa))
    npa <- nrow(X)
  if(npa != nrow(X)){
    cat("\n *** Error: need npa=nrow(X).\n")
    return(-1)
  }
  if(is.null(xgrid)){
    cat("\n *** Error: need xgrid, grid of time points to plot predictive.")
    cat("\n     specify as pair 'lo hi' for the interval (lo,hi).\n")
    return(-1)
  }

  fn <- file.path(data.dir,"init.p")
  out <- file(fn,open="w")
  cat(" n ",n,"\n",
      " p ",p,"\n",
      " sig ", sig,"\n",
      " nx ",nx,"\n",
      " xgrid from ", xgrid[1]," to ", xgrid[2],"\n",
      "npa ", npa, "\n",
      "px ", px,"\n",
      "data-z \n",
      rbind(format(t(X)),"\n"),
      file=out)
  close(out)

  if (length(j) != length(r)){
    cat("\n Error: need length(j)=length(r).\n")
    return(-1)
  }
  for(i in 1:length(j))
    {
      cat("\n Computing predictive for study ",j[i])
      if(r[i]==0)        cat(" with ")
      else               cat(" without ")
      cat(" common measure.\n")
      info <- .C("meta",j=j[i],r=r[i],package="meta")
      if(info != 0){
        cat("\n *** Error in predictive for (j,r)=(",j,r,").\n")
        return(-1)
      }
    }
}

  
j <- 1; r <- 0; i <- NULL; nx <- NULL
meta.predict <- function(j=1,   # study index
                          r=0,   # indicator for including the common measure
                          i=NULL,   # which patient (line in init.p)
                          nx=NULL, # grid length
                          data.dir=NULL, # directory for result files
                          plt=T)   # indicator for plotting 
{## plot posterior predictive for study j, using
 ## the idiosyncratic measure only (r=1) or including the common m. (r=0)

  if ( (length(r)>1) | (length(j)>1)){
    cat("\n *** Error: r and j need to be single integers.\n")
    return(-1)
  }
  if (!is.element(r,c(0,1))){ # r=0 or 1?
    cat("\n *** Error: need r = 0 or 1.\n")
    cat("    r=0: include common measure; r=1 idiosyncratic only.\n")
    return(-1)
  }
  fn <- file.path(data.dir,"xgrid.p")
  xgrid <- scan(fn)
  nx <- length(xgrid)
  ## matrix of covariates 'x-jr.p'
  fn <- file.path(data.dir,fjr("x",j,r))
  if (!file.exists(fn)){
    cat("\n *** Error: simulation results for (j,r)=",c(j,r))
    cat("\n     not found in directory ", data.dir)
    cat("\n Run 'meta.predict(.) first with (j,r).\n")
    return(-1)
  }
  X <- as.matrix(read.table(fn))
  npa <- nrow(X)
  if(is.null(i))
    i <- 1:npa
  else if(!is.element(i,1:npa)){
    cat("\n *** Error: need i \in {1,...,",npa,"}.")
    cat("\n (number of lines in 'x-jr.p'.\n")
    return(-1)
  }
  ## posterior predictive profiles 'e-jr.p', over xgrid
  fn <- file.path(data.dir,fjr("e",j,r))
  dta <- scan(fn)
  if (length(dta) %% nx != 0){
    cat("\n *** Error: 'xgrid.p' and 'e-jr.p' are not compatible.")
    cat("\n 'e-jr.p' does not have length(xgrid) columns for each patients.")
    cat("\n (j,r)=",c(j,r),"\n")
    return(-1)
  }
  if (length(dta) != nx*npa){
    cat("\n *** Error: length(e-jr.p) != nrow(x-jr.p)*length(xgrid.p).\n")
    cat("\n (j,r)=",c(j,r),"\n")
    return(-1)
  }
  e <- matrix(dta,byrow=T,ncol=nx)
  ## ... and s.d. 's-jr.p'
  fn <- file.path(data.dir,fjr("s",j,r))
  dta <- scan(fn)
  s <- matrix(dta,byrow=T,ncol=nx)
  ## plot if requested
  if(plt){
    ylim <- range(c(e-s,e+s))
    if(length(i)>1)
      matplot(xgrid,t(e[i,]),type="l",xlab="TIME",ylab="PREDICTIVE RESP",
              bty="l")
    else{
      plot(xgrid,e[i,],type="l",
           ylim=ylim,xlab="TIME",ylab="PREDICTIVE RESP",bty="l")
      lines(xgrid,e[i,]+s[i,],type="l",lty=2)
      lines(xgrid,e[i,]-s[i,],type="l",lty=2)
    }
  }
  return(list(xgrid=xgrid,e=e[i,],s=s[i,],x=X[i,]))
}


n <- 100; px <- 3; sig <- 1; nx <- 22;xgrid <- c(0,21);data.dir <- dir
meta.fitSetup <- 
  function(n=100,   # max MCMC iterations to use
           px=NULL, # dimension of cov vector
           sig=1,   # residual variance
           nx=25,   # size of grid for fit
           xgrid=NULL, # grid on time scale for fit
           data.dir=NULL)
  { ## evaluates fitted curves
    if (is.null(px))
      px <- 0 ## only used to write x.fit - for labeling purposes 
    if (is.null(xgrid)){
      cat("\n *** Error: xgrid required.\n")
      return(-1)
    }
    fn <- file.path(data.dir,"init.fit")
    out <- file(fn,open="w")
    cat(" n ",n,"\n",
        " px ",px,"\n",
        " sig ", sig,"\n",
        " nx ",nx,"\n",
        " xgrid from ", xgrid[1]," to ", xgrid[2],"\n",
        file=out)
    close(out)
    info <- .C("fit",package="meta")
    if(info != 0){
      cat("\n *** Error in fit.\n")
      return(-1)
    }
    fn <- file.path(data.dir,"e.fit")
    e <- matrix(scan(fn),byrow=T,ncol=nx)
    fn <- file.path(data.dir,"s.fit")
    s <- matrix(scan(fn),byrow=T,ncol=nx)
    npa <- nrwo(e)
    fn <- file.path(data.dir,"x.fit")
    dta <- scan(fn)
    px <- length(dta)/npa
    x.fit <- matrix(dta,byrow=T,ncol=px)
    return(list(e=e,s=s,x=x.fit))
  }


meta.fit <- function(fit.outp=NULL, i=NULL, data.dir=NULL)
  { ## plots the fitted profiles
    ## fit.struc=list(e,s,x), i.e., output from 'meta.fit()'
    if(is.null(fit.outp)){
      cat("\n *** Error: need argument fit.struc.")
      cat("\n     use 'meta.fit(.)' and save result fit.struc.\n")
      return(-1)
    }
    if(is.null(i))
      i <- 1:nrow(fit.outp$e)
    if(!all(is.element(i,1:nrow(fit.outp$e)))){
      cat("\n *** Error: need i in {1,...,npatients}.",
          "\n     using npatients=nrow(fit.outp$e).\n")
      return(-1)
    }
    if(is.null(data.dir)){
      data.dir <- getwd()
      cat("\n Using working directory ",data.dir,
          "\n Use argument 'data.dir' to change the directory.\n")
    }
    fn <- file.path(data.dir,"xgrid.fit")
    if (!file.exists(fn)){
      cat("\n *** Error: results from fit ",
          " not found in directory ", data.dir)
      cat("\n Run 'meta.fit(.) first.\n")
      return(-1)
    }
    xgrid <- scan(fn)
    ylim <- range(c(fit.outp$e + c(1,-1)*fit.outp$s))
    for(ii in i){
      e <- fit.outp$e[ii,]
      s <- fit.outp$s[ii,]
      plot(xgrid,e,type="l",bty="l",xlab="DAY",ylab="E(Y)",ylim=ylim)
      lines(xgrid,e-s,type="l",lty=2)
      lines(xgrid,e+s,type="l",lty=2)
      text(xgrid[1],ylim[1],labels=c(paste("I=",ii,sep="")),adj=-1)
    }
  }


 package.skeleton(name="meta",list=c("meta","meta.predictSetup",
    "meta.predict","meta.fitSetup","meta.fit"), path="/Users/pm/smooth/R/",
    namespace=T)                  
