\name{hdpmPredict}
\alias{hdpmPredict}
\title{Posterior predictive response}
\description{
  Plots posterior predictive response for assumed
  future patients.
  Must run \code{hdpmPredictSetup} first.
}
\usage{
hdpmPredict(j = 1, r = 0,
             i = NULL,
             work.dir = NULL, plt = T)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{j}{study}
  \item{r}{indicator for including (0) or not (1) the
    common measure.}
  \item{i}{index or vector of indices of future patients
    specified in the \code{X} in the earlier call to
    \code{hdpmPredictSetup}, i.e., row numbers in \code{X}.}
  \item{work.dir}{working directory where \code{hdpmPredictSetup}
    saved the posterior predictive simulations.}
  \item{plt}{indicator for plotting the predictive profiles.}
}
\details{
  Finds and plots posterior predictive mean and (point-wise) standard
  deviation of future responses for the indicated future
  patients.

  See \code{\link{hpdm-package}} for a statement of the probability
  model.
}
\value{
  Returns a list with
  \item{xgrid}{grid on the time axis}
  \item{e}{matrix of posterior predictive means with
    each row reporting \code{nx} mean responses for one patient.}
  \item{s}{posterior predictive s.d.}
  \item{x}{matrix with the covariates of the future patients, with
    one line per patient.}
}
\references
{
   Mueller, P., Quintana, F. and Rosner, G. (2004).
  ``Hierarchical Meta-Analysis over Related Non-parametric Bayesian
  Models.''
  Journal of the Royal Statistical Society, Series B, 66, 735--749.}
\author{Peter Mueller}
\note{
  The only functions in the source code that are specific
  to the application in Mueller et al. (2004) are the definition of the
  top level sampling model in the file \code{lpost.c}
  and the functions for resampling (transition probabilities in the
  MCMC) for the random effects in the source file \code{hdpm.c}. Both
  source files are in the directory \code{src} of the package
  distribution. Users with experience in coding MCMC could appropriately
  change these functions and recompile the package for a different
  longitudinal mean function.
}
\seealso{
  The functions in this package implement the application in
  \cite{Mueller et al. (2004).}
  Alternatively, the package
  \code{\link[hdpmn:hdpmn-package]{hdpmn}}
  implements the same hierarchical mixture of Dirichlet process models
  for a multivariate normal sampling model and is useful for
  a wider class of applications.
}
\examples{
\dontrun{
require(hdpm)

## data files
data.dir <- system.file("data",package="hdpm")
work.dir <- paste(getwd(),"/tmp/",sep="")
                  
## data files
Y <- file.path(data.dir,"CALGB.txt")
     ## data: responses
Z <- file.path(data.dir,"CALGBz.txt")  
     ## random effects (initial values) and covariates
X <- file.path(data.dir,"CALGBz0.txt")
     ## same as Z, for future patients (for prediction)

## run MCMC -- save working files in work.dir
hdpm(Y=Y,Z=Z,px=3,q=15,cc=15,work.dir=work.dir)

## post-process MCMC output for predictive inference
## save posterior predictive summaries in work.dir
hdpmPredictSetup(X=X,px=3,
                  j=c(0,1,2,1,2),r=c(0,0,0,1,1),
                  xgrid=c(0,21),work.dir=work.dir)

## plot predictive for future patients in study 1 and 2,
for(i in c(5,7)){
  hdpmPredict(j=1,r=0,i=i)
  hdpmPredict(j=2,r=0,i=i)
}

## part of the predictive corresponding to the idiosyncratic measure
for(i in c(5,7)){
  hdpmPredict(j=1,r=1,i=i, work.dir=work.dir)
  hdpmPredict(j=2,r=1,i=i, work.dir=work.dir)
}

## post-process MCMC output for fitted mean curves
fits <- hdpmFitSetup(px=3,xgrid=c(0,21))

## plot fitted mean curves 
par(mfrow=c(2,2),ask=T)
y <- as.matrix(read.table(Y,header=T)) # read in data
exs <- c(10:17,20:27,30:37,90:97)
for(i in exs){
  hdpmFit(fits,i=i)
  idx <- which(y[,1]==i-1)
  points(y[idx,2],y[idx,3],pch=19)
}
}
}
